nerves_runtime v0.8.0 Nerves.Runtime.KV behaviour
Key Value Storage for firmware variables provided by fwup
KV provides access to metadata variables set by fwup. It can be used to obtain information such as the active firmware slot, where the application data partition is located, etc.
Values are stored in two ways.
Values that do not pertain to a specific firmware slot For example:
"nerves_fw_active" => "a"Values that pertain to a specific firmware slot For Example:
"a.nerves_fw_author" => "The Nerves Team"
You can find values for just the active firmware slot by
using get_active and get_all_active. The result of these
functions will trim the firmware slot ("a." or "b.")
from the leading characters of the keys returned.
Link to this section Summary
Functions
Returns a specification to start this module under a supervisor
Get the key regardless of firmware slot
Get the key for only the active firmware slot
Get all keys regardless of firmware slot
Get all key value pairs for only the active firmware slot
Invoked when the server is started. start_link/3 or start/3 will
block until it returns
Start the KV store server
Link to this section Functions
Returns a specification to start this module under a supervisor.
See Supervisor.
Get the key regardless of firmware slot
Get the key for only the active firmware slot
Get all keys regardless of firmware slot
Get all key value pairs for only the active firmware slot
Invoked when the server is started. start_link/3 or start/3 will
block until it returns.
args is the argument term (second argument) passed to start_link/3.
Returning {:ok, state} will cause start_link/3 to return
{:ok, pid} and the process to enter its loop.
Returning {:ok, state, timeout} is similar to {:ok, state}
except handle_info(:timeout, state) will be called after timeout
milliseconds if no messages are received within the timeout.
Returning {:ok, state, :hibernate} is similar to {:ok, state}
except the process is hibernated before entering the loop. See
c:handle_call/3 for more information on hibernation.
Returning {:ok, state, {:continue, continue}} is similar to
{:ok, state} except that immediately after entering the loop
the c:handle_continue/2 callback will be invoked with the value
continue as first argument.
Returning :ignore will cause start_link/3 to return :ignore and
the process will exit normally without entering the loop or calling
c:terminate/2. If used when part of a supervision tree the parent
supervisor will not fail to start nor immediately try to restart the
GenServer. The remainder of the supervision tree will be started
and so the GenServer should not be required by other processes.
It can be started later with Supervisor.restart_child/2 as the child
specification is saved in the parent supervisor. The main use cases for
this are:
- The
GenServeris disabled by configuration but might be enabled later. - An error occurred and it will be handled by a different mechanism than the
Supervisor. Likely this approach involves callingSupervisor.restart_child/2after a delay to attempt a restart.
Returning {:stop, reason} will cause start_link/3 to return
{:error, reason} and the process to exit with reason reason without
entering the loop or calling c:terminate/2.
Callback implementation for GenServer.init/1.
Start the KV store server